@@ -63,8 +63,8 @@ getkey <- function(x = NULL) {
 		} else
 			if(class(key)=="character"){key <- key} else
 				{ stop("check your key input - it should be a character string") }
-	} else { 
-    key <- x 
+	} else {
+    key <- x
   }
 	key
 }
@@ -113,3 +113,11 @@ alm_GET <- function(x, y, sleep=0, ...){
   tt <- content(out, as = "text")
   jsonlite::fromJSON(tt, FALSE)
 }
+
+alm_POST <- function(x, y, sleep=0, ...){
+  Sys.sleep(time = sleep)
+  out <- POST(x, body=y, add_headers("X-HTTP-Method-Override" = "GET"), ...)
+  stop_for_status(out)
+  tt <- content(out, as = "text")
+  jsonlite::fromJSON(tt, FALSE)
+}
