@@ -1,12 +1,10 @@
 # tests for alm fxn in alm
 context("alm")
 
-key <- "rkfDr76z75benY3pytM1"
-
-dat <- alm_ids(doi="10.1371/journal.pone.0029797", key=key)
-dat2 <- alm_ids(doi='10.1371/journal.pone.0029797', info='detail', key=key)
-dat3 <- alm_ids(doi='10.1371/journal.pone.0035869', total_details=TRUE, key=key)
-dat4 <- alm_ids(doi='10.1371/journal.pone.0036240', sum_metrics='day', key=key)
+dat <- alm_ids(doi="10.1371/journal.pone.0029797")
+dat2 <- alm_ids(doi='10.1371/journal.pone.0029797', info='detail')
+dat3 <- alm_ids(doi='10.1371/journal.pone.0035869', total_details=TRUE)
+dat4 <- alm_ids(doi='10.1371/journal.pone.0036240', sum_metrics='day')
 
 test_that("alm returns the correct class", {
 	expect_that(dat, is_a("list"))
